@@ -19,7 +19,6 @@
 
 #include "homescreen.h"
 #include "applicationlistmodel.h"
-#include "colouraverage.h"
 
 #include <QtQml>
 #include <QDebug>
@@ -29,9 +28,6 @@ HomeScreen::HomeScreen(QObject *parent, const QVariantList &args)
     : Plasma::Containment(parent, args)
 {
     qmlRegisterUncreatableType<ApplicationListModel>("org.kde.phone.homescreen", 1, 0, "ApplicationListModel", QStringLiteral("Cannot create item of type ApplicationListModel"));
-    qmlRegisterSingletonType<ColourAverage>("org.kde.phone.homescreen", 1, 0, "ColourAverage", [](QQmlEngine *, QJSEngine *) -> QObject * {
-        return new ColourAverage();
-    });
 
     setHasConfigurationInterface(true);
 }
